Observability Framework
=======================

The observability framework is the part of Baseplate.py that integrates with
other Python application frameworks to bring automatic telemetry to your
application.

.. toctree::
   :titlesonly:

   baseplate: The skeleton of the telemetry framework <baseplate/index>
   baseplate.clients: Integration with client libraries <baseplate/clients/index>
   baseplate.frameworks: Integration with application frameworks <baseplate/frameworks/index>
   baseplate.observers: Diagnostics observers <baseplate/observers/index>

